diff -ru bahamut-release.old/config bahamut-release/config
--- bahamut-release.old/config	2003-04-05 16:21:17.000000000 +0200
+++ bahamut-release/config	2003-04-05 16:27:46.000000000 +0200
@@ -48,6 +48,7 @@
 LOCALKLINE="`grep 'SERVER_KLINE_ADDRESS' $OPTIONS_H | sed s/'.define SERVER_KLINE_ADDRESS '// | sed s/'\"'//g | xargs $ECHO`"
 NETWORKKLINE="`grep 'NETWORK_KLINE_ADDRESS' $OPTIONS_H | sed s/'.define NETWORK_KLINE_ADDRESS '// | sed s/'\"'//g | xargs $ECHO`"
 MAXCHANNELSPERUSER="`grep 'MAXCHANNELSPERUSER' $OPTIONS_H | sed s/'.define MAXCHANNELSPERUSER '// | xargs $ECHO`"
+STAFFADDRESS="`grep 'STAFF_ADDRESS' $OPTIONS_H | sed s/'.define STAFF_ADDRESS '// | xargs echo -n`"
 IRCDCONF_DELIMITER="`grep 'IRCDCONF_DELIMITER' $OPTIONS_H | sed s/'.define IRCDCONF_DELIMITER '// | xargs $ECHO`"
 #
 # Now to pull yucky defaults out.
@@ -183,30 +184,31 @@
 DPATH="`pwd`/"
 #SPATH="`pwd`/src/ircd" 
 STATSN="1"
-SMOTD="1"
-DEFINVIS="1"
+SMOTD=""
+DEFINVIS=""
 HUB=""
 WINGATE="1"
 SYSLOG="1"
-LOGKILL=""
-LOGSQUIT=""
-LOGCONN=""
+LOGKILL="1"
+LOGSQUIT="1"
+LOGCONN="1"
 SOPER=""
 USEPOLL=""
 MAXSENDQ="5050000"
 BUFPOOL="(4 * MAXSENDQLENGTH)"
 HULINED="1" 
-SERVICES_NAME="services.dal.net"
-MHOST="some.bot.host"
-LOCALKLINE="admin@poorly.configured.server.com"
-NETWORKKLINE="admin@poorly.configured.server.com"
-MAXCHANNELSPERUSER="10"
-CRYPTPASS=""
+SERVICES_NAME="services.rezosup.net"
+MHOST="sarah.rezosup.net"
+LOCALKLINE="misconfigured@rezosup.net"
+NETWORKKLINE="akill@rezosup.net"
+MAXCHANNELSPERUSER="20"
+CRYPTPASS="1"
 DOTHROTTLE="1"
 INET6=""
 IRCDCONF_DELIMITER=':'
 USE_SSL="1"
 ADMINSERV="1"
+STAFFADDRESS="staff.misconfigured.rezosup.net"
 
 fi # ENDIF $OPTIONS_H
 ###############################
@@ -214,7 +216,7 @@
 #  Ok, Now we Get into the accual configurations...
 
 echo " "
-echo "Welcome to Config for DALnet IRCD, Version:  $IRCD."
+echo "Welcome to Config for RezoSup IRCD, Version:  $IRCD."
 echo " "
 
 FOO=""
@@ -683,7 +685,7 @@
     echo ""
     echo "Would you like connecting users to be sent a notice regarding"
     echo "wingate and socks scans?  This must be defined if you"
-    echo "intend to run your server on DALnet."
+    echo "intend to run a public server."
     $ECHO "[$FOO] -> $c"
     if [ -z "$AUTO_CONFIG" -o -n "$runonce" ] ; then
         read cc
@@ -743,7 +745,7 @@
     echo "What address can users affected by k-lines ask for help?"
     echo "This is displayed to all LOCALLY k-lined users upon connect."
     echo "This should be the address of the local administrator."
-    echo "This should _NOT_ be kline@dal.net!"
+    echo "This should _NOT_ be akill@rezosup.net!"
     $ECHO "[$FOO] -> $c"
     if [ -z "$AUTO_CONFIG" -o -n "$runonce" ] ; then
         read cc
@@ -765,7 +767,7 @@
     echo "What address can users affected by autokills ask for help?"
     echo "This is displayed to all globally autokilled users upon connect."
     echo "This should be the address of the network administrator."
-    echo "On dalnet, this should be kline@dal.net."
+    echo "On RezoSup, this should be akill@rezosup.net."
     $ECHO "[$FOO] -> $c"
     if [ -z "$AUTO_CONFIG" -o -n "$runonce" ] ; then
         read cc
@@ -1038,7 +1040,7 @@
     fi
     echo ""
     echo "Do you want your server to hide U:lined servers in a /links?"
-    echo "If you are planning to link to DALnet, this MUST be defined."
+    echo "If you are planning to link to RezoSup, this MUST be defined."
     $ECHO "[$FOO] -> $c"
     if [ -z "$AUTO_CONFIG" -o -n "$runonce" ] ; then
 	read cc
@@ -1077,7 +1079,11 @@
    FOO=""
    runonce=""
    while [ -z "$FOO" ] ; do
+    	if [ -n "$USEPOLL" ] ; then
        FOO="Yes"
+		else
+  		FOO="No"
+		  fi
        echo ""
        echo "Do you want to use the poll system call?"
        echo "If you are on a solaris machine, this is mandatory."
@@ -1119,7 +1125,7 @@
     echo "If you have network services and would like to make use of "
     echo "the built in secure services aliasing features, type in the "
     echo "name of your network services server here. If you are a "
-    echo "DALnet admin, you would type in \"services.dal.net\" below."
+    echo "RezoSup admin, you would type in \"services.rezosup.net\" below."
     $ECHO "[$FOO] -> $c"
     if [ -z "$AUTO_CONFIG" -o -n "$runonce" -o -z "$SERVICES_NAME" ] ; then
 	read cc
@@ -1295,6 +1301,30 @@
     fi
 fi
 
+echo "***************************************"
+echo "Start of RezoSup specific configuration"
+echo "***************************************"
+echo ""
+
+FOO=""
+runonce=""
+while [ -z "$FOO" ] ; do
+    FOO="$STAFFADDRESS"
+    echo ""
+    echo "What is the staff for hostmasked clients ?"
+    echo -n "[$FOO] -> $c"
+    if [ -z "$AUTO_CONFIG" -o -n "$runonce" ] ; then
+        read cc
+        runonce=Yes
+    else
+        cc=""
+    fi
+    if [ -z "$cc" ] ; then
+        cc=$FOO
+    fi
+done
+STAFFADDRESS="$cc"
+
 #############
 # Thats all for the user part, now to write to a file...
 
@@ -1330,6 +1360,7 @@
 #define MAX_BUFFER $MAXBUF
 #define SERVICES_NAME "$SERVICES_NAME"
 #define MAXCHANNELSPERUSER $MAXCHANNELSPERUSER
+#define STAFF_ADDRESS "$STAFFADDRESS"
 #define IRCDCONF_DELIMITER '$IRCDCONF_DELIMITER'
 EOF
 if [ -n "$INET6" ] ; then
diff -ru bahamut-release.old/include/config.h bahamut-release/include/config.h
--- bahamut-release.old/include/config.h	2003-04-05 16:21:17.000000000 +0200
+++ bahamut-release/include/config.h	2003-04-05 16:31:39.000000000 +0200
@@ -152,9 +152,9 @@
  * you use syslog above, you may want to turn some (none) of the
  * spurious log messages for KILL,SQUIT,etc off.
  */
-#undef	SYSLOG_KILL		/* log all operator kills */
-#undef	SYSLOG_SQUIT	        /* log all remote squits */
-#undef	SYSLOG_CONNECT	        /* log remote connect messages */
+#define	SYSLOG_KILL		/* log all operator kills */
+#define	SYSLOG_SQUIT	        /* log all remote squits */
+#define	SYSLOG_CONNECT	        /* log remote connect messages */
 #undef	SYSLOG_USERS		/* send userlog stuff to syslog */
 #undef	SYSLOG_OPER		/* log all users who successfully oper */
 #undef   SYSLOG_BLOCK_ALLOCATOR /* debug block allocator */
@@ -185,7 +185,7 @@
  * Define this if you want to hide the location of U:lined servers (and 
  * then clients on them) from nonopers. With this defined, no non-oper 
  * should be able to find out which server the U:lined server is connected
- * to. If you are connected to the main DALnet network, you MUST have this
+ * to. If you are connected to the RezoSup network, you MUST have this
  * enabled.
  */
 #define HIDEULINEDSERVS 1
@@ -210,7 +210,7 @@
 #endif
 
 /* Services Name */
-#define SERVICES_NAME "services.dal.net"	/* DALnet services */
+#define SERVICES_NAME "services.rezosup.net"	/* Rezosup services */
 
 /*
  * CRYPT_OPER_PASSWORD - use crypted oper passwords in the ircd.conf
@@ -223,9 +223,16 @@
  * MAXCHANNELSPERUSER - Max number of channels a user is allowed to
  * join.
  */
-#define MAXCHANNELSPERUSER  10	/* Recommended value: 10 */
+#define MAXCHANNELSPERUSER  20	/* Recommended value: 10 */
 #define THROTTLE_ENABLE /* enable throttling, see below */
 
+/*
+ * STAFF_ADDRESS
+ *
+ * Hostmask for staff when oper hostmasking is used.
+ */
+#define STAFF_ADDRESS "staff.misconfigured.rezosup.net"
+
 /*******************************************************/
 
 #endif /** OPTIONS_H **/
@@ -269,7 +276,7 @@
 
 
 /* Services Definitions */
-#define STATS_NAME "stats.dal.net"
+#define STATS_NAME "statserv.rezosup.net"
 #define CHANSERV "ChanServ"
 #define NICKSERV "NickServ"
 #define MEMOSERV "MemoServ"
@@ -281,9 +288,9 @@
 #define CHANSERVATSERVICES CHANSERV "@" SERVICES_NAME
 #define MEMOSERVATSERVICES MEMOSERV "@" SERVICES_NAME
 #define ROOTSERVATSERVICES ROOTSERV "@" SERVICES_NAME
-#define OPERSERVATSTATS    OPERSERV "@" STATS_NAME
+#define OPERSERVATSTATS    OPERSERV "@" SERVICES_NAME
 #define STATSERVATSTATS    STATSERV "@" STATS_NAME
-#define HELPSERVATSTATS    HELPSERV "@" STATS_NAME
+#define HELPSERVATSTATS    HELPSERV "@" SERVICES_NAME
 
 /*
  * FNAME_USERLOG and FNAME_OPERLOG - logs of local USERS and OPERS
@@ -352,7 +359,7 @@
  * if not defined, only allow 1 connection per listening socket 
  * every two seconds.
  */
-#define CONNECTFAST
+#undef CONNECTFAST
 
 /*
  * LOCKFILE - Exclusive use of ircd.conf and kline.conf during writes
@@ -618,7 +625,7 @@
  * RK_NOTICES - Show notices when rline/kline'd connections are denied.
  * This generates a TON of crap, I reccomend leaving it undef'd.
  */
-#undef RK_NOTICES
+#define RK_NOTICES
 
 /*
  * ANTI_NICK_FLOOD - prevents nick flooding define if you want to block
@@ -689,16 +696,7 @@
  * Rather self explanitory. If not specified in T: line,
  * we tell clients to go to "http://<this>"
  */
-#define DEFAULT_PROXY_INFO_URL "kline.dal.net/proxy"
-
-/*
- * STAFF_ADDRESS
- *
- * Hostmask for staff when oper hostmasking is used.
- * If you are actually a dalnet server, you should not change this.
- * The idea is to make it universal for the entire network.
- */
-#define STAFF_ADDRESS "DALnet"
+#define DEFAULT_PROXY_INFO_URL "www.rezosup.org/proxy.phtml"
 
 /*
  * RIDICULOUS_PARANOIA_LEVEL
@@ -711,10 +709,6 @@
  * 2 - Local +A can see the real IP.
  * 3 - Noone can see the real IP.  It is still logged.
  *
- * WARNING:
- * Running levels above 1 on DALnet will result in your server being juped
- * from the network if a security breech is suspected.
- *
  * If level 3 is selected, USE_SYSLOG must be defined.
  */
 #define RIDICULOUS_PARANOIA_LEVEL 1
@@ -771,7 +765,7 @@
  * NOTE: This *MUST* be greater than 1024 if you plan to run ircd under
  * any other uid than root.
  */
-#define PORTNUM 7000 /* 7000 for DALnet */
+#define PORTNUM 6667
 
 /*
  * MAXCONNECTIONS - don't touch - change the HARD_FDLIMIT_ instead
diff -ru bahamut-release.old/include/patchlevel.h bahamut-release/include/patchlevel.h
--- bahamut-release.old/include/patchlevel.h	2003-04-05 16:21:17.000000000 +0200
+++ bahamut-release/include/patchlevel.h	2003-04-05 16:34:18.000000000 +0200
@@ -45,7 +45,7 @@
 #define PATCH2 "+ssl(1.1)"
 #endif
 
-#define PATCH3 ""
+#define PATCH3 "+rz1e"
 
 #define PATCH4 ""
 
diff -ru bahamut-release.old/src/s_serv.c bahamut-release/src/s_serv.c
--- bahamut-release.old/src/s_serv.c	2003-04-05 16:21:17.000000000 +0200
+++ bahamut-release/src/s_serv.c	2003-04-05 16:21:42.000000000 +0200
@@ -1539,6 +1539,16 @@
 		       TS_MAX_DELTA, TS_WARN_DELTA);
 	    sendto_one(sptr, rpl_str(RPL_INFO),
 		       me.name, parv[0], outstr);
+
+/* Display RezoSup specific variables */
+#ifdef WINGATE_NOTICE
+      strcpy(outstr, " WINGATE_NOTICE=1");
+#else
+      strcpy(outstr, " WINGATE_NOTICE=0");
+#endif
+      sendto_one(sptr, rpl_str(RPL_INFO),
+           me.name, parv[0], outstr);
+
 	}
 
 	sendto_one(sptr,


diff -ru bahamut-release.old/src/s_err.c bahamut-release/src/s_err.c
--- bahamut-release.old/src/s_err.c	2003-04-05 16:21:17.000000000 +0200
+++ bahamut-release/src/s_err.c	2003-04-05 16:21:42.000000000 +0200
@@ -21,7 +21,7 @@
 static char *replies[] = 
 {
     /* 000 */	NULL,
     /* 001 RPL_WELCOME */	":%s 001 %s :Welcome to the DALnet IRC "
                                 "Network %s!%s@%s",
     /* 002 RPL_YOURHOST */	":%s 002 %s :Your host is %s, running "
                                 "version %s",
@@ -31,7 +31,7 @@
     /* 005 RPL_PROTOCTL*/       ":%s 005 %s NOQUIT WATCH=%i SAFELIST MODES=%i "
                                 "MAXCHANNELS=%i MAXBANS=%i NICKLEN=%i "
                                 "TOPICLEN=%i KICKLEN=%i CHANTYPES=&# "
-                                "PREFIX=(ov)@+ NETWORK=DALnet SILENCE=%i "
+                                "PREFIX=(ov)@+ NETWORK=RezoSup SILENCE=%i "
                                 "CASEMAPPING=ascii "
                                 ":are available on this server",
     /* 006 */	                NULL,
@@ -549,7 +549,7 @@
     /* 486 ERR_NONONREG */	":%s 486 %s :You must identify to a "
                                 "registered nick to private message %s",
     /* 487 ERR_MSGSERVICES */	":%s 487 %s :Error! \"/msg %s\" is no longer supported. "
-                                "Use \"/msg %s@services.dal.net\" or \"/%s\" instead.",
+                                "Use \"/msg %s@services.rezosup.net\" or \"/%s\" instead.",
     /* 488 */	                NULL,
     /* 489 */	                NULL,	/* In use by Undernet */
     /* 490 */	                NULL,
@@ -21,7 +21,7 @@
 {
     /* 000 */	NULL,
-    /* 001 RPL_WELCOME */	":%s 001 %s :Welcome to the DALnet IRC "
+    /* 001 RPL_WELCOME */	":%s 001 %s :Welcome to RezoSup IRC "
                                 "Network %s!%s@%s",
     /* 002 RPL_YOURHOST */	":%s 002 %s :Your host is %s, running "